#!/usr/bin/env python

from email.mime.message import MIMEMessage
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from smtplib import LMTP, SMTP

MESSAGE_SENDER = "imip-agent@example.com"

MESSAGE_SUBJECT = "Calendar system message"

MESSAGE_TEXT = """\
This is a response to a calendar message sent by your calendar program.
"""

PREAMBLE_TEXT = """\
This message contains several different parts, one of which will contain
calendar information that will only be understood by a suitable program.
"""

class Messenger:

    "Sending of outgoing messages."

    def __init__(self, sender=None, subject=None, body_text=None, preamble_text=None):
        self.sender = sender or MESSAGE_SENDER
        self.subject = subject or MESSAGE_SUBJECT
        self.body_text = body_text or MESSAGE_TEXT
        self.preamble_text = preamble_text or PREAMBLE_TEXT

    def sendmail(self, recipients, data, sender=None, lmtp_socket=None):

        """
        Send a mail to the given 'recipients' consisting of the given 'data',
        using the given 'sender' identity if indicated, delivering to a local
        mail system using LMTP if 'lmtp_socket' is provided.
        """

        if lmtp_socket:
            smtp = LMTP(lmtp_socket)
        else:
            smtp = SMTP("localhost")

        smtp.sendmail(sender or self.sender, recipients, data)
        smtp.quit()

    def make_message(self, parts, recipients, sender=None):

        """
        Make a message from the given 'parts' for the given 'recipients', using
        the given 'sender' identity if indicated.
        """

        message = MIMEMultipart("mixed", _subparts=parts)
        message.preamble = self.preamble_text
        payload = message.get_payload()
        payload.insert(0, MIMEText(self.body_text))

        message["From"] = sender or self.sender
        for recipient in recipients:
            message["To"] = recipient
        message["Subject"] = self.subject

        return message

    def wrap_message(self, msg, parts):

        "Wrap 'msg' and provide the given 'parts' as the primary content."

        message = MIMEMultipart("mixed", _subparts=parts)
        message.preamble = self.preamble_text
        payload = message.get_payload()
        payload.insert(0, MIMEText(self.body_text))
        payload.append(MIMEMessage(msg))

        message["From"] = msg["From"]
        message["To"] = msg["To"]
        message["Subject"] = msg["Subject"]

        return message

# vim: tabstop=4 expandtab shiftwidth=4
